.onLoad <- function(libname, pkgname) {

.jinit(parameters="-Xmx512m",force.init=TRUE)
.jpackage(pkgname)
  
}  
